Exception: Html2rss::Config::ParamsMissing
- Inherits:
-
StandardError
- Object
- StandardError
- Html2rss::Config::ParamsMissing
- Defined in:
- lib/html2rss/config.rb
Overview
The Error class to be thrown when a feed config requires params, but none were passed to Config.