Class: Html2rss::RssBuilder::Article

Inherits:
Object
  • Object
show all
Includes:
Comparable, Enumerable
Defined in:
lib/html2rss/rss_builder/article.rb

Overview

Article is a simple data object representing an article extracted from a page. It is enumerable and responds to all keys specified in PROVIDED_KEYS.

Constant Summary collapse

PROVIDED_KEYS =

Allowed article attributes accepted by the value object constructor.

%i[id title description url image author guid published_at enclosures categories scraper].freeze
DEDUP_FINGERPRINT_SEPARATOR =

Separator used to build deterministic deduplication fingerprints.

'#!/'

Instance Method Summary collapse

Constructor Details

#initialize(**options) ⇒ Article

Returns a new instance of Article.

Parameters:

  • options (Hash{Symbol => String})

Options Hash (**options):

  • :id (String)

    stable article identifier

  • :title (String)

    article title

  • :description (String)

    article description/content

  • :url (String, Html2rss::Url)

    canonical article URL

  • :image (String, Html2rss::Url)

    image URL for fallback enclosure rendering

  • :author (String)

    author name

  • :guid (String)

    explicit GUID override

  • :published_at (String, Time, DateTime)

    publication timestamp

  • :enclosures (Array<Hash{Symbol => Object}>)

    enclosure attribute hashes

  • :categories (Array<String>)

    category labels

  • :scraper (Class)

    scraper class that produced the article



33
34
35
36
37
38
39
40
41
# File 'lib/html2rss/rss_builder/article.rb', line 33

def initialize(**options)
  @to_h = {}
  options.each_pair { |key, value| @to_h[key] = value.freeze if value }
  @to_h.freeze

  return unless (unknown_keys = options.keys - PROVIDED_KEYS).any?

  Log.warn "Article: unknown keys found: #{unknown_keys.join(', ')}"
end

Instance Method Details

#<=>(other) ⇒ Integer?

Returns comparison result for compatible Article values.

Parameters:

  • other (Object)

    value compared against this article

Returns:

  • (Integer, nil)

    comparison result for compatible Article values



147
148
149
150
151
# File 'lib/html2rss/rss_builder/article.rb', line 147

def <=>(other)
  return nil unless other.is_a?(Article)

  0 if other.all? { |key, value| value == public_send(key) ? public_send(key) <=> value : false }
end

#authorString?

Returns:

  • (String, nil)


85
# File 'lib/html2rss/rss_builder/article.rb', line 85

def author = blank_string_to_nil(@to_h[:author])

#categoriesArray<String>

Returns normalized, unique category names.

Returns:

  • (Array<String>)

    normalized, unique category names



122
123
124
125
126
127
128
# File 'lib/html2rss/rss_builder/article.rb', line 122

def categories
  @categories ||= @to_h[:categories].dup.to_a.tap do |categories|
    categories.map! { |category| category.to_s.strip }
    categories.reject!(&:empty?)
    categories.uniq!
  end
end

#deduplication_fingerprintString, Integer

Returns a deterministic fingerprint used to detect duplicate articles.

Returns:

  • (String, Integer)


97
98
99
# File 'lib/html2rss/rss_builder/article.rb', line 97

def deduplication_fingerprint
  dedup_from_url || dedup_from_id || dedup_from_guid || hash
end

#descriptionString

Returns rendered article description.

Returns:

  • (String)

    rendered article description



64
65
66
67
68
69
70
71
72
# File 'lib/html2rss/rss_builder/article.rb', line 64

def description
  @description ||= Rendering::DescriptionBuilder.new(
    base: @to_h[:description],
    title:,
    url:,
    enclosures:,
    image:
  ).call
end

#each {|key, value| ... } ⇒ Enumerator

Returns if no block is given.

Yields:

  • (key, value)

Returns:

  • (Enumerator)

    if no block is given



51
52
53
54
55
# File 'lib/html2rss/rss_builder/article.rb', line 51

def each
  return enum_for(:each) unless block_given?

  PROVIDED_KEYS.each { |key| yield(key, public_send(key)) }
end

#enclosureHtml2rss::RssBuilder::Enclosure?



108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/html2rss/rss_builder/article.rb', line 108

def enclosure
  return @enclosure if defined?(@enclosure)

  case (object = @to_h[:enclosures]&.first)
  when Hash
    @enclosure = Html2rss::RssBuilder::Enclosure.new(**object)
  when nil
    @enclosure = Html2rss::RssBuilder::Enclosure.new(url: image) if image
  else
    Log.warn "Article: unknown enclosure type: #{object.class}"
  end
end

#enclosuresArray<Html2rss::RssBuilder::Enclosure>

Returns normalized enclosure objects.

Returns:



102
103
104
105
# File 'lib/html2rss/rss_builder/article.rb', line 102

def enclosures
  @enclosures ||= Array(@to_h[:enclosures])
                  .map { |enclosure| Html2rss::RssBuilder::Enclosure.new(**enclosure) }
end

#guidString

Generates a unique identifier based on the URL and ID using CRC32.

Returns:

  • (String)


89
90
91
# File 'lib/html2rss/rss_builder/article.rb', line 89

def guid
  @guid ||= Zlib.crc32(fetch_guid).to_s(36).encode('utf-8')
end

#idString?

Returns stable article identifier.

Returns:

  • (String, nil)

    stable article identifier



58
# File 'lib/html2rss/rss_builder/article.rb', line 58

def id = blank_string_to_nil(@to_h[:id])

#imageUrl?

Returns:



80
81
82
# File 'lib/html2rss/rss_builder/article.rb', line 80

def image
  @image ||= Url.sanitize(@to_h[:image])
end

#published_atDateTime?

Parses and returns the published_at time.

Returns:

  • (DateTime, nil)


132
133
134
135
136
137
138
# File 'lib/html2rss/rss_builder/article.rb', line 132

def published_at
  return if (string = @to_h[:published_at].to_s.strip).empty?

  @published_at ||= DateTime.parse(string)
rescue ArgumentError
  nil
end

#scraperClass?

Returns scraper class that produced this article.

Returns:

  • (Class, nil)

    scraper class that produced this article



141
142
143
# File 'lib/html2rss/rss_builder/article.rb', line 141

def scraper
  @to_h[:scraper]
end

#titleString?

Returns article title.

Returns:

  • (String, nil)

    article title



61
# File 'lib/html2rss/rss_builder/article.rb', line 61

def title = blank_string_to_nil(@to_h[:title])

#urlUrl?

Returns:



75
76
77
# File 'lib/html2rss/rss_builder/article.rb', line 75

def url
  @url ||= Url.sanitize(@to_h[:url])
end

#valid?Boolean

Checks if the article is valid based on the presence of URL, ID, and either title or description.

Returns:

  • (Boolean)

    True if the article is valid, otherwise false.



45
46
47
# File 'lib/html2rss/rss_builder/article.rb', line 45

def valid?
  !url.to_s.empty? && (!title.to_s.empty? || !description.to_s.empty?) && !id.to_s.empty?
end